@@ -1,6 +1,6 @@
 /*============================================================================
-  WCSLIB 8.2 - an implementation of the FITS WCS standard.
-  Copyright (C) 1995-2023, Mark Calabretta
+  WCSLIB 8.4 - an implementation of the FITS WCS standard.
+  Copyright (C) 1995-2024, Mark Calabretta
 
   This file is part of WCSLIB.
 
@@ -19,7 +19,7 @@
 
   Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
   http://www.atnf.csiro.au/people/Mark.Calabretta
-  $Id: tcel2.c,v 8.2.1.1 2023/11/16 10:05:58 mcalabre Exp mcalabre $
+  $Id: tcel2.c,v 8.4 2024/10/28 13:56:17 mcalabre Exp $
 *=============================================================================
 *
 * tcel2 thoroughly tests the WCSLIB celestial coordinate transformation
@@ -179,7 +179,10 @@ int main()
       celestial.theta0 = -90.0;
     }
 
-    celestial.prj = native.prj;
+    // Copy projection parameters.
+    strcpy(celestial.prj.code, native.prj.code);
+    celestial.prj.pv[1] = native.prj.pv[1];
+    celestial.prj.pv[2] = native.prj.pv[2];
 
     // Loop over CRVAL2, CRVAL1 and LONPOLE.
     crval1_j  = -180;
@@ -566,6 +569,9 @@ int main()
         crval2_i  = 45;
       }
     }
+
+    celfree(&native);
+    celfree(&celestial);
   }
 
 end:
