@@ -1,6 +1,6 @@
 /*============================================================================
-  WCSLIB 8.2 - an implementation of the FITS WCS standard.
-  Copyright (C) 1995-2023, Mark Calabretta
+  WCSLIB 8.4 - an implementation of the FITS WCS standard.
+  Copyright (C) 1995-2024, Mark Calabretta
 
   This file is part of WCSLIB.
 
@@ -19,7 +19,7 @@
 
   Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
   http://www.atnf.csiro.au/people/Mark.Calabretta
-  $Id: cel_f.c,v 8.2.1.1 2023/11/16 10:05:58 mcalabre Exp mcalabre $
+  $Id: cel_f.c,v 8.4 2024/10/28 13:56:17 mcalabre Exp $
 *===========================================================================*/
 
 #include <stdio.h>
@@ -43,12 +43,24 @@
 #define celini_  F77_FUNC(celini,  CELINI)
 #define celfree_ F77_FUNC(celfree, CELFREE)
 #define celsize_ F77_FUNC(celsize, CELSIZE)
+#define celenq_  F77_FUNC(celenq,  CELENQ)
 #define celprt_  F77_FUNC(celprt,  CELPRT)
 #define celperr_ F77_FUNC(celperr, CELPERR)
 #define celset_  F77_FUNC(celset,  CELSET)
 #define celx2s_  F77_FUNC(celx2s,  CELX2S)
 #define cels2x_  F77_FUNC(cels2x,  CELS2X)
 
+#ifdef BINDC
+  #undef  celptc_
+  #define celptc_ celptc_c
+
+  #undef  celgtc_
+  #define celgtc_ celgtc_c
+
+  #undef  celperr_
+  #define celperr_ celperr_c
+#endif
+
 // Must match the values set in cel.inc.
 #define CEL_FLAG   100
 #define CEL_OFFSET 101
@@ -67,19 +79,19 @@
 int celput_(int *cel, const int *what, const void *value, const int *i)
 
 {
-  unsigned int l;
-  int *icelp;
-  const int    *ivalp;
-  const double *dvalp;
-  struct celprm *celp;
-
   // Cast pointers.
-  celp  = (struct celprm *)cel;
-  ivalp = (const int *)value;
-  dvalp = (const double *)value;
+  struct celprm *celp = (struct celprm *)cel;
+  const int    *ivalp = (const int *)value;
+  const double *dvalp = (const double *)value;
 
-  celp->flag = 0;
+  if (celp->flag == 1 || celp->flag < 0) {
+    // Preserve bypass mode.
+    celp->flag = 1;
+  } else {
+    celp->flag = 0;
+  }
 
+  int *icelp;
   switch (*what) {
   case CEL_FLAG:
     celp->flag = *ivalp;
@@ -98,7 +110,7 @@ int celput_(int *cel, const int *what, const void *value, const int *i)
     break;
   case CEL_PRJ:
     icelp = cel + ((int *)(&(celp->prj)) - (int *)celp);
-    for (l = 0; l < PRJLEN; l++) {
+    for (size_t l = 0; l < PRJLEN; l++) {
       *(icelp++) = *(ivalp++);
     }
     break;
@@ -129,18 +141,12 @@ int celpti_(int *cel, const int *what, const int *value, const int *i)
 int celget_(const int *cel, const int *what, void *value)
 
 {
-  unsigned int l;
-  int k;
-  int    *ivalp;
-  double *dvalp;
-  const int *icelp;
-  const struct celprm *celp;
-
   // Cast pointers.
-  celp  = (const struct celprm *)cel;
-  ivalp = (int *)value;
-  dvalp = (double *)value;
+  const struct celprm *celp = (const struct celprm *)cel;
+  int    *ivalp = (int *)value;
+  double *dvalp = (double *)value;
 
+  const int *icelp;
   switch (*what) {
   case CEL_FLAG:
     *ivalp = celp->flag;
@@ -155,18 +161,18 @@ int celget_(const int *cel, const int *what, void *value)
     *dvalp = celp->theta0;
     break;
   case CEL_REF:
-    for (k = 0; k < 4; k++) {
+    for (int k = 0; k < 4; k++) {
       *(dvalp++) = celp->ref[k];
     }
     break;
   case CEL_PRJ:
     icelp = (int *)(&(celp->prj));
-    for (l = 0; l < PRJLEN; l++) {
+    for (size_t l = 0; l < PRJLEN; l++) {
       *(ivalp++) = *(icelp++);
     }
     break;
   case CEL_EULER:
-    for (k = 0; k < 5; k++) {
+    for (int k = 0; k < 5; k++) {
        *(dvalp++) = celp->euler[k];
     }
     break;
@@ -180,11 +186,11 @@ int celget_(const int *cel, const int *what, void *value)
     // Copy the contents of the wcserr struct.
     if (celp->err) {
       icelp = (int *)(celp->err);
-      for (l = 0; l < ERRLEN; l++) {
+      for (size_t l = 0; l < ERRLEN; l++) {
         *(ivalp++) = *(icelp++);
       }
     } else {
-      for (l = 0; l < ERRLEN; l++) {
+      for (size_t l = 0; l < ERRLEN; l++) {
         *(ivalp++) = 0;
       }
     }
@@ -237,6 +243,14 @@ int celsize_(const int *cel, int sizes[2])
 
 //----------------------------------------------------------------------------
 
+int celenq_(const int *cel, int *enquiry)
+
+{
+  return celenq((const struct celprm *)cel, *enquiry);
+}
+
+//----------------------------------------------------------------------------
+
 int celprt_(const int *cel)
 
 {
@@ -256,13 +270,12 @@ int celprt_(const int *cel)
 int celperr_(int *cel, const char prefix[72])
 
 {
-  char prefix_[73];
-  wcsutil_strcvt(72, '\0', 1, prefix, prefix_);
-
   // This may or may not force the Fortran I/O buffers to be flushed.
   // If not, try CALL FLUSH(6) before calling CELPERR in the Fortran code.
   fflush(NULL);
 
+  char prefix_[73];
+  wcsutil_strcvt(72, '\0', 1, prefix, prefix_);
   return celperr((struct celprm *)cel, prefix_);
 }
 
