@@ -1,6 +1,6 @@
 /*============================================================================
-  WCSLIB 8.2 - an implementation of the FITS WCS standard.
-  Copyright (C) 1995-2023, Mark Calabretta
+  WCSLIB 8.4 - an implementation of the FITS WCS standard.
+  Copyright (C) 1995-2024, Mark Calabretta
 
   This file is part of WCSLIB.
 
@@ -19,7 +19,7 @@
 
   Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
   http://www.atnf.csiro.au/people/Mark.Calabretta
-  $Id: dis_f.c,v 8.2.1.1 2023/11/16 10:05:58 mcalabre Exp mcalabre $
+  $Id: dis_f.c,v 8.4 2024/10/28 13:56:17 mcalabre Exp $
 *=============================================================================
 *
 * In these wrappers, if
@@ -62,6 +62,7 @@
 #define discpy_   F77_FUNC(discpy,   DISCPY)
 #define disfree_  F77_FUNC(disfree,  DISFREE)
 #define dissize_  F77_FUNC(dissize,  DISSIZE)
+#define disenq_   F77_FUNC(disenq,   DISENQ)
 #define disprt_   F77_FUNC(disprt,   DISPRT)
 #define disperr_  F77_FUNC(disperr,  DISPERR)
 #define dishdo_   F77_FUNC(dishdo,   DISHDO)
@@ -70,6 +71,20 @@
 #define disx2p_   F77_FUNC(disx2p,   DISX2P)
 #define diswarp_  F77_FUNC(diswarp,  DISWARP)
 
+#ifdef BINDC
+  #undef  disptc_
+  #define disptc_ disptc_c
+
+  #undef  disgtc_
+  #define disgtc_ disgtc_c
+
+  #undef  dpfill_
+  #define dpfill_ dpfill_c
+
+  #undef  disperr_
+  #define disperr_ disperr_c
+#endif
+
 // Must match the values set in dis.inc.
 #define DIS_FLAG   100
 #define DIS_NAXIS  101
@@ -117,29 +132,28 @@ int disput_(
   const int *dummy)
 
 {
-  int j0;
-  const char *cvalp;
-  const int  *ivalp;
-  const double *dvalp;
-  struct disprm *disp;
-
   // Avert nuisance compiler warnings about unused parameters.
   (void)dummy;
 
   // Cast pointers.
+  struct disprm *disp;
   if (*deref == 0) {
     disp = (struct disprm *)dis;
   } else {
     disp = *(struct disprm **)dis;
   }
 
-  cvalp = (const char *)value;
-  ivalp = (const int *)value;
-  dvalp = (const double *)value;
+  const char   *cvalp = (const char *)value;
+  const int    *ivalp = (const int *)value;
+  const double *dvalp = (const double *)value;
 
   // Convert 1-relative FITS (and Fortran) axis numbers and parameter
   // indices to 0-relative C array indices.
-  j0 = *j - 1;
+  int j0 = *j - 1;
+
+  // Preserve bypass mode.
+  int flag = 0;
+  if (disp->flag == 1 || disp->flag < 0) flag = 1;
 
   switch (*what) {
   case DIS_FLAG:
@@ -147,7 +161,7 @@ int disput_(
     break;
   case DIS_NAXIS:
     disp->naxis = *ivalp;
-    disp->flag = 0;
+    disp->flag = flag;
     break;
   case DIS_DTYPE:
     wcsutil_strcvt(72, '\0', 0, cvalp, disp->dtype[j0]);
@@ -161,7 +175,7 @@ int disput_(
     // Use DPFILL to create the struct.
     memcpy((char *)(disp->dp + disp->ndp), cvalp, DPLEN*sizeof(int));
     (disp->ndp)++;
-    disp->flag = 0;
+    disp->flag = flag;
     break;
   case DIS_TOTDIS:
     disp->totdis = *dvalp;
@@ -199,26 +213,19 @@ int dispti_(const int *deref, int *dis, const int *what, const int *value,
 int disget_(const int *deref, const int *dis, const int *what, void *value)
 
 {
-  unsigned int l;
-  int j, k, naxis;
-  char   *cvalp;
-  int    *ivalp;
-  double *dvalp;
-  const int    *idisp;
-  const struct disprm *disp;
-
   // Cast pointers.
+  const struct disprm *disp;
   if (*deref == 0) {
     disp = (const struct disprm *)dis;
   } else {
     disp = *(const struct disprm **)dis;
   }
 
-  cvalp = (char *)value;
-  ivalp = (int *)value;
-  dvalp = (double *)value;
+  char   *cvalp = (char *)value;
+  int    *ivalp = (int *)value;
+  double *dvalp = (double *)value;
 
-  naxis = disp->naxis;
+  int naxis = disp->naxis;
 
   switch (*what) {
   case DIS_FLAG:
@@ -228,7 +235,7 @@ int disget_(const int *deref, const int *dis, const int *what, void *value)
     *ivalp = naxis;
     break;
   case DIS_DTYPE:
-    for (j = 0; j < naxis; j++) {
+    for (int j = 0; j < naxis; j++) {
       wcsutil_strcvt(72, ' ', 0, disp->dtype[j], cvalp);
       cvalp += 72;
     }
@@ -246,51 +253,51 @@ int disget_(const int *deref, const int *dis, const int *what, void *value)
     *dvalp = disp->totdis;
     break;
   case DIS_MAXDIS:
-    for (j = 0; j < naxis; j++) {
+    for (int j = 0; j < naxis; j++) {
       *(dvalp++) = disp->maxdis[j];
     }
     break;
   case DIS_DOCORR:
-    for (j = 0; j < naxis; j++) {
+    for (int j = 0; j < naxis; j++) {
       *(ivalp++) = disp->docorr[j];
     }
     break;
   case DIS_NHAT:
-    for (j = 0; j < naxis; j++) {
+    for (int j = 0; j < naxis; j++) {
       *(ivalp++) = disp->Nhat[j];
     }
     break;
   case DIS_AXMAP:
-    for (j = 0; j < naxis; j++) {
-      for (k = 0; k < naxis; k++) {
+    for (int j = 0; j < naxis; j++) {
+      for (int k = 0; k < naxis; k++) {
         *(ivalp++) = disp->axmap[j][k];
       }
     }
     break;
   case DIS_OFFSET:
-    for (j = 0; j < naxis; j++) {
-      for (k = 0; k < naxis; k++) {
+    for (int j = 0; j < naxis; j++) {
+      for (int k = 0; k < naxis; k++) {
         *(dvalp++) = disp->offset[j][k];
       }
     }
     break;
   case DIS_SCALE:
-    for (j = 0; j < naxis; j++) {
-      for (k = 0; k < naxis; k++) {
+    for (int j = 0; j < naxis; j++) {
+      for (int k = 0; k < naxis; k++) {
         *(dvalp++) = disp->scale[j][k];
       }
     }
     break;
   case DIS_IPARM:
-    for (j = 0; j < naxis; j++) {
-      for (k = 0; k < disp->iparm[j][0]; k++) {
+    for (int j = 0; j < naxis; j++) {
+      for (int k = 0; k < disp->iparm[j][0]; k++) {
         *(ivalp++) = disp->iparm[j][k];
       }
     }
     break;
   case DIS_DPARM:
-    for (j = 0; j < naxis; j++) {
-      for (k = 0; k < disp->iparm[j][1]; k++) {
+    for (int j = 0; j < naxis; j++) {
+      for (int k = 0; k < disp->iparm[j][1]; k++) {
         *(dvalp++) = disp->dparm[j][k];
       }
     }
@@ -304,12 +311,12 @@ int disget_(const int *deref, const int *dis, const int *what, void *value)
   case DIS_ERR:
     // Copy the contents of the wcserr struct.
     if (disp->err) {
-      idisp = (int *)(disp->err);
-      for (l = 0; l < ERRLEN; l++) {
+      const int *idisp = (int *)(disp->err);
+      for (size_t l = 0; l < ERRLEN; l++) {
         *(ivalp++) = *(idisp++);
       }
     } else {
-      for (l = 0; l < ERRLEN; l++) {
+      for (size_t l = 0; l < ERRLEN; l++) {
         *(ivalp++) = 0;
       }
     }
@@ -387,7 +394,6 @@ int disini_(const int *deref, const int *naxis, int *dis)
 
 {
   struct disprm *disp;
-
   if (*deref == 0) {
     disp = (struct disprm *)dis;
   } else {
@@ -403,7 +409,6 @@ int disinit_(const int *deref, const int *naxis, int *dis, int *ndpmax)
 
 {
   struct disprm *disp;
-
   if (*deref == 0) {
     disp = (struct disprm *)dis;
   } else {
@@ -419,14 +424,13 @@ int discpy_(const int *deref, const int *dissrc, int *disdst)
 
 {
   const struct disprm *dissrcp;
-  struct disprm *disdstp;
-
   if ((*deref&1) == 0) {
     dissrcp = (const struct disprm *)dissrc;
   } else {
     dissrcp = *(const struct disprm **)dissrc;
   }
 
+  struct disprm *disdstp;
   if ((*deref&2) == 0) {
     disdstp = (struct disprm *)disdst;
   } else {
@@ -442,7 +446,6 @@ int disfree_(const int *deref, int *dis)
 
 {
   struct disprm *disp;
-
   if (*deref == 0) {
     disp = (struct disprm *)dis;
   } else {
@@ -462,11 +465,18 @@ int dissize_(const int *dis, int sizes[2])
 
 //----------------------------------------------------------------------------
 
+int disenq_(const int *dis, int *enquiry)
+
+{
+  return disenq((const struct disprm *)dis, *enquiry);
+}
+
+//----------------------------------------------------------------------------
+
 int disprt_(const int *deref, const int *dis)
 
 {
   const struct disprm *disp;
-
   if (*deref == 0) {
     disp = (const struct disprm *)dis;
   } else {
@@ -512,7 +522,6 @@ int dishdo_(const int *deref, int *dis)
 
 {
   struct disprm *disp;
-
   if (*deref == 0) {
     disp = (struct disprm *)dis;
   } else {
@@ -528,7 +537,6 @@ int disset_(const int *deref, int *dis)
 
 {
   struct disprm *disp;
-
   if (*deref == 0) {
     disp = (struct disprm *)dis;
   } else {
@@ -548,7 +556,6 @@ int disp2x_(
 
 {
   struct disprm *disp;
-
   if (*deref == 0) {
     disp = (struct disprm *)dis;
   } else {
@@ -568,7 +575,6 @@ int disx2p_(
 
 {
   struct disprm *disp;
-
   if (*deref == 0) {
     disp = (struct disprm *)dis;
   } else {
