@@ -1,6 +1,6 @@
 /*============================================================================
-  WCSLIB 8.2 - an implementation of the FITS WCS standard.
-  Copyright (C) 1995-2023, Mark Calabretta
+  WCSLIB 8.4 - an implementation of the FITS WCS standard.
+  Copyright (C) 1995-2024, Mark Calabretta
 
   This file is part of WCSLIB.
 
@@ -19,7 +19,7 @@
 
   Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
   http://www.atnf.csiro.au/people/Mark.Calabretta
-  $Id: spc_f.c,v 8.2.1.1 2023/11/16 10:05:58 mcalabre Exp mcalabre $
+  $Id: spc_f.c,v 8.4 2024/10/28 13:56:17 mcalabre Exp $
 *===========================================================================*/
 
 #include <stdio.h>
@@ -43,6 +43,7 @@
 #define spcini_  F77_FUNC(spcini,  SPCINI)
 #define spcfree_ F77_FUNC(spcfree, SPCFREE)
 #define spcsize_ F77_FUNC(spcsize, SPCSIZE)
+#define spcenq_  F77_FUNC(spcenq,  SPCENQ)
 #define spcprt_  F77_FUNC(spcprt,  SPCPRT)
 #define spcperr_ F77_FUNC(spcperr, SPCPERR)
 #define spcset_  F77_FUNC(spcset,  SPCSET)
@@ -60,6 +61,40 @@
 #define spcxps_  F77_FUNC(spcxps,  SPCXPS)
 #define spctrn_  F77_FUNC(spctrn,  SPCTRN)
 
+#ifdef BINDC
+  #undef  spcptc_
+  #define spcptc_ spcptc_c
+
+  #undef  spcgtc_
+  #define spcgtc_ spcgtc_c
+
+  #undef  spcperr_
+  #define spcperr_ spcperr_c
+
+  #undef  spctype_ 
+  #define spctype_ spctype_c
+  #undef  spctyp_ 
+  #define spctyp_  spctyp_c
+
+  #undef  spcspxe_ 
+  #define spcspxe_ spcspxe_c
+  #undef  spcspx_ 
+  #define spcspx_  spcspx_c
+
+  #undef  spcxpse_ 
+  #define spcxpse_ spcxpse_c
+  #undef  spcxps_ 
+  #define spcxps_  spcxps_c
+
+  #undef  spctrne_ 
+  #define spctrne_ spctrne_c
+  #undef  spctrn_ 
+  #define spctrn_  spctrn_c
+
+  #undef  spcaips_ 
+  #define spcaips_ spcaips_c
+#endif
+
 // Must match the values set in spc.inc.
 #define SPC_FLAG    100
 #define SPC_TYPE    101
@@ -78,18 +113,18 @@
 int spcput_(int *spc, const int *what, const void *value, const int *m)
 
 {
-  const char *cvalp;
-  const int  *ivalp;
-  const double *dvalp;
-  struct spcprm *spcp;
-
   // Cast pointers.
-  spcp  = (struct spcprm *)spc;
-  cvalp = (const char *)value;
-  ivalp = (const int *)value;
-  dvalp = (const double *)value;
+  struct spcprm *spcp = (struct spcprm *)spc;
+  const char   *cvalp = (const char *)value;
+  const int    *ivalp = (const int *)value;
+  const double *dvalp = (const double *)value;
 
-  spcp->flag = 0;
+  if (spcp->flag == 1 || spcp->flag < 0) {
+    // Preserve bypass mode.
+    spcp->flag = 1;
+  } else {
+    spcp->flag = 0;
+  }
 
   switch (*what) {
   case SPC_FLAG:
@@ -144,19 +179,11 @@ int spcpti_(int *spc, const int *what, const int *value, const int *m)
 int spcget_(const int *spc, const int *what, void *value)
 
 {
-  unsigned int l;
-  int  m;
-  char *cvalp;
-  int  *ivalp;
-  double *dvalp;
-  const int *ispcp;
-  const struct spcprm *spcp;
-
   // Cast pointers.
-  spcp  = (const struct spcprm *)spc;
-  cvalp = (char *)value;
-  ivalp = (int *)value;
-  dvalp = (double *)value;
+  const struct spcprm *spcp = (const struct spcprm *)spc;
+  char   *cvalp = (char *)value;
+  int    *ivalp = (int *)value;
+  double *dvalp = (double *)value;
 
   switch (*what) {
   case SPC_FLAG:
@@ -178,12 +205,12 @@ int spcget_(const int *spc, const int *what, void *value)
     *dvalp = spcp->restwav;
     break;
   case SPC_PV:
-    for (m = 0; m < 7; m++) {
+    for (int m = 0; m < 7; m++) {
       *(dvalp++) = spcp->pv[m];
     }
     break;
   case SPC_W:
-    for (m = 0; m < 6; m++) {
+    for (int m = 0; m < 6; m++) {
       *(dvalp++) = spcp->w[m];
     }
     break;
@@ -193,12 +220,12 @@ int spcget_(const int *spc, const int *what, void *value)
   case SPC_ERR:
     // Copy the contents of the wcserr struct.
     if (spcp->err) {
-      ispcp = (int *)(spcp->err);
-      for (l = 0; l < ERRLEN; l++) {
+      const int *ispcp = (int *)(spcp->err);
+      for (size_t l = 0; l < ERRLEN; l++) {
         *(ivalp++) = *(ispcp++);
       }
     } else {
-      for (l = 0; l < ERRLEN; l++) {
+      for (size_t l = 0; l < ERRLEN; l++) {
         *(ivalp++) = 0;
       }
     }
@@ -251,6 +278,14 @@ int spcsize_(const int *spc, int sizes[2])
 
 //----------------------------------------------------------------------------
 
+int spcenq_(const int *spc, int *enquiry)
+
+{
+  return spcenq((const struct spcprm *)spc, *enquiry);
+}
+
+//----------------------------------------------------------------------------
+
 int spcprt_(const int *spc)
 
 {
@@ -270,13 +305,12 @@ int spcprt_(const int *spc)
 int spcperr_(int *spc, const char prefix[72])
 
 {
-  char prefix_[73];
-  wcsutil_strcvt(72, '\0', 1, prefix, prefix_);
-
   // This may or may not force the Fortran I/O buffers to be flushed.
   // If not, try CALL FLUSH(6) before calling SPCPERR in the Fortran code.
   fflush(NULL);
 
+  char prefix_[73];
+  wcsutil_strcvt(72, '\0', 1, prefix, prefix_);
   return wcserr_prt(((struct spcprm *)spc)->err, prefix_);
 }
 
