@@ -1,6 +1,6 @@
 /*============================================================================
-  WCSLIB 8.1 - an implementation of the FITS WCS standard.
-  Copyright (C) 1995-2023, Mark Calabretta
+  WCSLIB 8.4 - an implementation of the FITS WCS standard.
+  Copyright (C) 1995-2024, Mark Calabretta
 
   This file is part of WCSLIB.
 
@@ -19,7 +19,7 @@
 
   Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
   http://www.atnf.csiro.au/people/Mark.Calabretta
-  $Id: spx_f.c,v 8.1 2023/07/05 17:12:07 mcalabre Exp $
+  $Id: spx_f.c,v 8.4 2024/10/28 13:56:17 mcalabre Exp $
 *===========================================================================*/
 
 #include <string.h>
@@ -33,6 +33,11 @@
 #define spxget_ F77_FUNC(spxget, SPXGET)
 #define specx_  F77_FUNC(specx,  SPECX)
 
+#ifdef BINDC
+  #undef  specx_
+  #define specx_ specx_c
+#endif
+
 // Must match the value set in spx.inc.
 #define SPX_ERR     200
 
