@@ -1,6 +1,6 @@
 /*============================================================================
-  WCSLIB 8.2 - an implementation of the FITS WCS standard.
-  Copyright (C) 1995-2023, Mark Calabretta
+  WCSLIB 8.4 - an implementation of the FITS WCS standard.
+  Copyright (C) 1995-2024, Mark Calabretta
 
   This file is part of WCSLIB.
 
@@ -19,7 +19,7 @@
 
   Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
   http://www.atnf.csiro.au/people/Mark.Calabretta
-  $Id: tab_f.c,v 8.2.1.1 2023/11/16 10:05:58 mcalabre Exp mcalabre $
+  $Id: tab_f.c,v 8.4 2024/10/28 13:56:17 mcalabre Exp $
 *===========================================================================*/
 
 #include <stdio.h>
@@ -44,12 +44,18 @@
 #define tabcmp_  F77_FUNC(tabcmp,  TABCMP)
 #define tabfree_ F77_FUNC(tabfree, TABFREE)
 #define tabsize_ F77_FUNC(tabsize, TABSIZE)
+#define tabenq_  F77_FUNC(tabenq,  TABENQ)
 #define tabprt_  F77_FUNC(tabprt,  TABPRT)
 #define tabperr_ F77_FUNC(tabperr, TABPERR)
 #define tabset_  F77_FUNC(tabset,  TABSET)
 #define tabx2s_  F77_FUNC(tabx2s,  TABX2S)
 #define tabs2x_  F77_FUNC(tabs2x,  TABS2X)
 
+#ifdef BINDC
+  #undef  tabperr_
+  #define tabperr_ tabperr_c
+#endif
+
 // Must match the value set in tab.inc.
 #define TAB_FLAG     100
 #define TAB_M        101
@@ -76,21 +82,21 @@ int tabput_(
   const int *k)
 
 {
-  int k0, m0;
-  const int  *ivalp;
-  const double *dvalp;
-  struct tabprm *tabp;
-
   // Cast pointers.
-  tabp  = (struct tabprm *)tab;
-  ivalp = (const int *)value;
-  dvalp = (const double *)value;
+  struct tabprm *tabp = (struct tabprm *)tab;
+  const int    *ivalp = (const int *)value;
+  const double *dvalp = (const double *)value;
 
   // Convert 1-relative FITS axis numbers to 0-relative C array indices.
-  m0 = *m - 1;
-  k0 = *k - 1;
+  int m0 = *m - 1;
+  int k0 = *k - 1;
 
-  tabp->flag = 0;
+  if (tabp->flag == 1 || tabp->flag < 0) {
+    // Preserve bypass mode.
+    tabp->flag = 1;
+  } else {
+    tabp->flag = 0;
+  }
 
   switch (*what) {
   case TAB_FLAG:
@@ -138,18 +144,12 @@ int tabpti_(int *tab, const int *what, const int *value, const int *m,
 int tabget_(const int *tab, const int *what, void *value)
 
 {
-  unsigned int l;
-  int i, k, m, n;
-  int    *ivalp;
-  double *dvalp;
-  const int *itabp;
-  const struct tabprm *tabp;
-
   // Cast pointers.
-  tabp  = (const struct tabprm *)tab;
-  ivalp = (int *)value;
-  dvalp = (double *)value;
+  const struct tabprm *tabp = (const struct tabprm *)tab;
+  int    *ivalp = (int *)value;
+  double *dvalp = (double *)value;
 
+  int n;
   switch (*what) {
   case TAB_FLAG:
     *ivalp = tabp->flag;
@@ -158,23 +158,23 @@ int tabget_(const int *tab, const int *what, void *value)
     *ivalp = tabp->M;
     break;
   case TAB_K:
-    for (m = 0; m < tabp->M; m++) {
+    for (int m = 0; m < tabp->M; m++) {
       *(ivalp++) = tabp->K[m];
     }
     break;
   case TAB_MAP:
-    for (m = 0; m < tabp->M; m++) {
+    for (int m = 0; m < tabp->M; m++) {
       *(ivalp++) = tabp->map[m];
     }
     break;
   case TAB_CRVAL:
-    for (m = 0; m < tabp->M; m++) {
+    for (int m = 0; m < tabp->M; m++) {
       *(dvalp++) = tabp->crval[m];
     }
     break;
   case TAB_INDEX:
-    for (m = 0; m < tabp->M; m++) {
-      for (k = 0; k < tabp->K[m]; k++) {
+    for (int m = 0; m < tabp->M; m++) {
+      for (int k = 0; k < tabp->K[m]; k++) {
         *(dvalp++) = tabp->index[m][k];
       }
     }
@@ -182,11 +182,11 @@ int tabget_(const int *tab, const int *what, void *value)
   case TAB_COORD:
     // Don't rely on tabprm.nc being set.
     n = tabp->M;
-    for (m = 0; m < tabp->M; m++) {
+    for (int m = 0; m < tabp->M; m++) {
       n *= tabp->K[m];
     }
 
-    for (i = 0; i < n; i++) {
+    for (int i = 0; i < n; i++) {
       *(dvalp++) = tabp->coord[i];
     }
     break;
@@ -194,39 +194,39 @@ int tabget_(const int *tab, const int *what, void *value)
     *ivalp = tabp->nc;
     break;
   case TAB_SENSE:
-    for (m = 0; m < tabp->M; m++) {
+    for (int m = 0; m < tabp->M; m++) {
       *(ivalp++) = tabp->sense[m];
     }
     break;
   case TAB_P0:
-    for (m = 0; m < tabp->M; m++) {
+    for (int m = 0; m < tabp->M; m++) {
       *(ivalp++) = tabp->p0[m];
     }
     break;
   case TAB_DELTA:
-    for (m = 0; m < tabp->M; m++) {
+    for (int m = 0; m < tabp->M; m++) {
       *(dvalp++) = tabp->delta[m];
     }
     break;
   case TAB_EXTREMA:
     n = 2 * tabp->M;
-    for (m = 1; m < tabp->M; m++) {
+    for (int m = 1; m < tabp->M; m++) {
       n *= tabp->K[m];
     }
 
-    for (i = 0; i < n; i++) {
+    for (int i = 0; i < n; i++) {
       *(dvalp++) = tabp->extrema[i];
     }
     break;
   case TAB_ERR:
     // Copy the contents of the wcserr struct.
     if (tabp->err) {
-      itabp = (int *)(tabp->err);
-      for (l = 0; l < ERRLEN; l++) {
+      const int *itabp = (int *)(tabp->err);
+      for (size_t l = 0; l < ERRLEN; l++) {
         *(ivalp++) = *(itabp++);
       }
     } else {
-      for (l = 0; l < ERRLEN; l++) {
+      for (size_t l = 0; l < ERRLEN; l++) {
         *(ivalp++) = 0;
       }
     }
@@ -304,6 +304,14 @@ int tabsize_(const int *tab, int sizes[2])
 
 //----------------------------------------------------------------------------
 
+int tabenq_(const int *tab, int *enquiry)
+
+{
+  return tabenq((const struct tabprm *)tab, *enquiry);
+}
+
+//----------------------------------------------------------------------------
+
 int tabprt_(const int *tab)
 
 {
@@ -323,13 +331,12 @@ int tabprt_(const int *tab)
 int tabperr_(int *tab, const char prefix[72])
 
 {
-  char prefix_[73];
-  wcsutil_strcvt(72, '\0', 1, prefix, prefix_);
-
   // This may or may not force the Fortran I/O buffers to be flushed.
   // If not, try CALL FLUSH(6) before calling TABPERR in the Fortran code.
   fflush(NULL);
 
+  char prefix_[73];
+  wcsutil_strcvt(72, '\0', 1, prefix, prefix_);
   return wcserr_prt(((struct tabprm *)tab)->err, prefix_);
 }
 
