@@ -1,7 +1,7 @@
 *=======================================================================
 *
-* WCSLIB 8.2 - an implementation of the FITS WCS standard.
-* Copyright (C) 1995-2023, Mark Calabretta
+* WCSLIB 8.4 - an implementation of the FITS WCS standard.
+* Copyright (C) 1995-2024, Mark Calabretta
 *
 * This file is part of WCSLIB.
 *
@@ -20,7 +20,7 @@
 *
 * Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
 * http://www.atnf.csiro.au/people/Mark.Calabretta
-* $Id: tspc.f,v 8.2.1.1 2023/11/16 10:05:58 mcalabre Exp mcalabre $
+* $Id: tspc.f,v 8.4 2024/10/28 13:56:17 mcalabre Exp $
 *=======================================================================
 
       PROGRAM TSPC
@@ -330,7 +330,7 @@
 *     Test closure.
       NFAIL = 0
       RESIDMAX = 0D0
-      STATUS = SPCGTC (SPC, SPC_TYPE, STYPE, 0)
+      STATUS = SPCGTC (SPC, SPC_TYPE, STYPE)
       DO 90 J = 1, NAXISJ
         IF (STAT1(J).NE.0) THEN
           WRITE (*, 60) CTYPES, SPEC1(J), STYPE, STAT1(J)
