@@ -1,7 +1,7 @@
 *=======================================================================
 *
-* WCSLIB 8.2 - an implementation of the FITS WCS standard.
-* Copyright (C) 1995-2023, Mark Calabretta
+* WCSLIB 8.4 - an implementation of the FITS WCS standard.
+* Copyright (C) 1995-2024, Mark Calabretta
 *
 * This file is part of WCSLIB.
 *
@@ -20,7 +20,7 @@
 *
 * Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
 * http://www.atnf.csiro.au/people/Mark.Calabretta
-* $Id: twcsfix.f,v 8.2.1.1 2023/11/16 10:05:58 mcalabre Exp mcalabre $
+* $Id: twcsfix.f,v 8.4 2024/10/28 13:56:17 mcalabre Exp $
 *=======================================================================
 
       PROGRAM TWCSFIX
@@ -51,7 +51,7 @@
      :          OBSGEO_L, PC(N,N), PHI, PIXCRD(N), RESTFRQ, RESTWAV,
      :          THETA, WORLD(N)
       CHARACTER CTYPE(N)*72, CUNIT(N)*72, DATEAVG*72, DATEBEG*72,
-     :          DATEEND*72, DATEOBS*72, SPECSYS*72
+     :          DATEEND*72, DATEOBS*72, RADESYS*72, SPECSYS*72
 
       COMMON /HEADER/ CRPIX, PC, CDELT, CRVAL, RESTFRQ, RESTWAV, BEPOCH,
      :          MJDBEG, OBSGEO_L, OBSGEO_B, OBSGEO_H, EQUINOX, NAXIS,
@@ -154,8 +154,9 @@
 *     been constructed with the galactic pole coincident with the native
 *     pole of the projection in order to test the resolution of an
 *     indeterminacy.
+      RADESYS = CHAR(0)
       STATUS = WCSCCS (WCS1, 123.0D0, 27.4D0, 192.25D0, 'GLON', 'GLAT',
-     :                 CHAR(0), 0D0, 'G')
+     :                 RADESYS, 0D0, 'G')
       IF (STATUS.NE.0) THEN
         STATUS = WCSPERR (WCS1, CHAR(0))
         GO TO 999
