@@ -1,6 +1,6 @@
 /*============================================================================
-  WCSLIB 8.2 - an implementation of the FITS WCS standard.
-  Copyright (C) 1995-2023, Mark Calabretta
+  WCSLIB 8.4 - an implementation of the FITS WCS standard.
+  Copyright (C) 1995-2024, Mark Calabretta
 
   This file is part of WCSLIB.
 
@@ -19,7 +19,7 @@
 
   Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
   http://www.atnf.csiro.au/people/Mark.Calabretta
-  $Id: wcs_f.c,v 8.2.1.1 2023/11/16 10:05:58 mcalabre Exp mcalabre $
+  $Id: wcs_f.c,v 8.4 2024/10/28 13:56:17 mcalabre Exp $
 *===========================================================================*/
 
 #include <stdio.h>
@@ -52,6 +52,7 @@
 #define wcstrim_ F77_FUNC(wcstrim, WCSTRIM)
 #define wcssize_ F77_FUNC(wcssize, WCSSIZE)
 #define auxsize_ F77_FUNC(auxsize, AUXSIZE)
+#define wcsenq_  F77_FUNC(wcsenq,  WCSENQ)
 #define wcsprt_  F77_FUNC(wcsprt,  WCSPRT)
 #define wcsperr_ F77_FUNC(wcsperr, WCSPERR)
 #define wcsbchk_ F77_FUNC(wcsbchk, WCSBCHK)
@@ -64,6 +65,26 @@
 #define wcscopy_ F77_FUNC(wcscopy, WCSCOPY)
 #define wcslib_version_ F77_FUNC(wcslib_version, WCSLIB_VERSION)
 
+#ifdef BINDC
+  #undef  wcsptc_
+  #define wcsptc_ wcsptc_c
+
+  #undef  wcsgtc_
+  #define wcsgtc_ wcsgtc_c
+
+  #undef  wcsperr_
+  #define wcsperr_ wcsperr_c
+
+  #undef  wcsccs_
+  #define wcsccs_ wcsccs_c
+
+  #undef  wcssptr_
+  #define wcssptr_ wcssptr_c
+
+  #undef  wcslib_version_
+  #define wcslib_version_ wcslib_version_c
+#endif
+
 // Must match the value set in wcs.inc.
 #define WCS_FLAG     100
 #define WCS_NAXIS    101
@@ -179,7 +200,7 @@ int wcsput_(
   const int *j)
 
 {
-  int i0, j0, k;
+  int k;
   const char *cvalp;
   const int  *ivalp;
   const double *dvalp;
@@ -191,9 +212,13 @@ int wcsput_(
   ivalp = (const int *)value;
   dvalp = (const double *)value;
 
+  // Preserve bypass mode.
+  int flag = 0;
+  if (wcsp->flag == 1 || wcsp->flag < 0) flag = 1;
+
   // Convert 1-relative FITS axis numbers to 0-relative C array indices.
-  i0 = *i - 1;
-  j0 = *j - 1;
+  int i0 = *i - 1;
+  int j0 = *j - 1;
 
   switch (*what) {
   case WCS_FLAG:
@@ -201,48 +226,48 @@ int wcsput_(
     break;
   case WCS_NAXIS:
     wcsp->naxis = *ivalp;
-    wcsp->flag = 0;
+    wcsp->flag = flag;
     break;
   case WCS_CRPIX:
     wcsp->crpix[i0] = *dvalp;
-    wcsp->flag = 0;
+    wcsp->flag = flag;
     break;
   case WCS_PC:
     k = (i0)*(wcsp->naxis) + (j0);
     *(wcsp->pc+k) = *dvalp;
-    wcsp->flag = 0;
+    wcsp->flag = flag;
     break;
   case WCS_CDELT:
     wcsp->cdelt[i0] = *dvalp;
-    wcsp->flag = 0;
+    wcsp->flag = flag;
     break;
   case WCS_CRVAL:
     wcsp->crval[i0] = *dvalp;
-    wcsp->flag = 0;
+    wcsp->flag = flag;
     break;
   case WCS_CUNIT:
     wcsutil_strcvt(72, '\0', 0, cvalp, wcsp->cunit[i0]);
-    wcsp->flag = 0;
+    wcsp->flag = flag;
     break;
   case WCS_CTYPE:
     wcsutil_strcvt(72, '\0', 0, cvalp, wcsp->ctype[i0]);
-    wcsp->flag = 0;
+    wcsp->flag = flag;
     break;
   case WCS_LONPOLE:
     wcsp->lonpole = *dvalp;
-    wcsp->flag = 0;
+    wcsp->flag = flag;
     break;
   case WCS_LATPOLE:
     wcsp->latpole = *dvalp;
-    wcsp->flag = 0;
+    wcsp->flag = flag;
     break;
   case WCS_RESTFRQ:
     wcsp->restfrq = *dvalp;
-    wcsp->flag = 0;
+    wcsp->flag = flag;
     break;
   case WCS_RESTWAV:
     wcsp->restwav = *dvalp;
-    wcsp->flag = 0;
+    wcsp->flag = flag;
     break;
   case WCS_NPV:
   case WCS_NPVMAX:
@@ -253,7 +278,7 @@ int wcsput_(
     (wcsp->pv + wcsp->npv)->m = *j;
     (wcsp->pv + wcsp->npv)->value = *dvalp;
     (wcsp->npv)++;
-    wcsp->flag = 0;
+    wcsp->flag = flag;
     break;
   case WCS_NPS:
   case WCS_NPSMAX:
@@ -264,20 +289,20 @@ int wcsput_(
     (wcsp->ps + wcsp->nps)->m = *j;
     wcsutil_strcvt(72, '\0', 0, cvalp, (wcsp->ps + wcsp->nps)->value);
     (wcsp->nps)++;
-    wcsp->flag = 0;
+    wcsp->flag = flag;
     break;
   case WCS_CD:
     k = (i0)*(wcsp->naxis) + (j0);
     *(wcsp->cd+k) = *dvalp;
-    wcsp->flag = 0;
+    wcsp->flag = flag;
     break;
   case WCS_CROTA:
     wcsp->crota[i0] = *dvalp;
-    wcsp->flag = 0;
+    wcsp->flag = flag;
     break;
   case WCS_ALTLIN:
     wcsp->altlin = *ivalp;
-    wcsp->flag = 0;
+    wcsp->flag = flag;
     break;
   case WCS_VELREF:
     wcsp->velref = *ivalp;
@@ -510,23 +535,15 @@ int wcspti_(int *wcs, const int *what, const int *value, const int *i,
 int wcsget_(const int *wcs, const int *what, void *value)
 
 {
-  unsigned int l;
-  int i, j, k, naxis;
-  char   *cvalp;
-  int    *ivalp;
-  double *dvalp;
-  const int    *iwcsp;
-  const double *dwcsp;
-  const struct wcsprm *wcsp;
-
   // Cast pointers.
-  wcsp  = (const struct wcsprm *)wcs;
-  cvalp = (char *)value;
-  ivalp = (int *)value;
-  dvalp = (double *)value;
+  const struct wcsprm *wcsp = (const struct wcsprm *)wcs;
+  char   *cvalp = (char *)value;
+  int    *ivalp = (int *)value;
+  double *dvalp = (double *)value;
 
-  naxis = wcsp->naxis;
+  int naxis = wcsp->naxis;
 
+  const int *iwcsp;
   switch (*what) {
   case WCS_FLAG:
     *ivalp = wcsp->flag;
@@ -535,38 +552,38 @@ int wcsget_(const int *wcs, const int *what, void *value)
     *ivalp = naxis;
     break;
   case WCS_CRPIX:
-    for (i = 0; i < naxis; i++) {
+    for (int i = 0; i < naxis; i++) {
       *(dvalp++) = wcsp->crpix[i];
     }
     break;
   case WCS_PC:
     // C row-major to FORTRAN column-major.
-    for (j = 0; j < naxis; j++) {
-      dwcsp = wcsp->pc + j;
-      for (i = 0; i < naxis; i++) {
+    for (int j = 0; j < naxis; j++) {
+      const double *dwcsp = wcsp->pc + j;
+      for (int i = 0; i < naxis; i++) {
         *(dvalp++) = *dwcsp;
         dwcsp += naxis;
       }
     }
     break;
   case WCS_CDELT:
-    for (i = 0; i < naxis; i++) {
+    for (int i = 0; i < naxis; i++) {
       *(dvalp++) = wcsp->cdelt[i];
     }
     break;
   case WCS_CRVAL:
-    for (i = 0; i < naxis; i++) {
+    for (int i = 0; i < naxis; i++) {
       *(dvalp++) = wcsp->crval[i];
     }
     break;
   case WCS_CUNIT:
-    for (i = 0; i < naxis; i++) {
+    for (int i = 0; i < naxis; i++) {
       wcsutil_strcvt(72, ' ', 0, wcsp->cunit[i], cvalp);
       cvalp += 72;
     }
     break;
   case WCS_CTYPE:
-    for (i = 0; i < naxis; i++) {
+    for (int i = 0; i < naxis; i++) {
       wcsutil_strcvt(72, ' ', 0, wcsp->ctype[i], cvalp);
       cvalp += 72;
     }
@@ -590,7 +607,7 @@ int wcsget_(const int *wcs, const int *what, void *value)
     *ivalp = wcsp->npvmax;
     break;
   case WCS_PV:
-    for (k = 0; k < wcsp->npv; k++) {
+    for (int k = 0; k < wcsp->npv; k++) {
       *(dvalp++) = (wcsp->pv + k)->i;
       *(dvalp++) = (wcsp->pv + k)->m;
       *(dvalp++) = (wcsp->pv + k)->value;
@@ -603,7 +620,7 @@ int wcsget_(const int *wcs, const int *what, void *value)
     *ivalp = wcsp->npsmax;
     break;
   case WCS_PS:
-    for (k = 0; k < wcsp->nps; k++) {
+    for (int k = 0; k < wcsp->nps; k++) {
       *(dvalp++) = (wcsp->ps + k)->i;
       *(dvalp++) = (wcsp->ps + k)->m;
       cvalp += 2*sizeof(double);
@@ -613,16 +630,16 @@ int wcsget_(const int *wcs, const int *what, void *value)
     break;
   case WCS_CD:
     // C row-major to FORTRAN column-major.
-    for (j = 0; j < naxis; j++) {
-      dwcsp = wcsp->cd + j;
-      for (i = 0; i < naxis; i++) {
+    for (int j = 0; j < naxis; j++) {
+      const double *dwcsp = wcsp->cd + j;
+      for (int i = 0; i < naxis; i++) {
         *(dvalp++) = *dwcsp;
         dwcsp += naxis;
       }
     }
     break;
   case WCS_CROTA:
-    for (i = 0; i < naxis; i++) {
+    for (int i = 0; i < naxis; i++) {
       *(dvalp++) = wcsp->crota[i];
     }
     break;
@@ -640,34 +657,34 @@ int wcsget_(const int *wcs, const int *what, void *value)
     *ivalp = wcsp->colnum;
     break;
   case WCS_COLAX:
-    for (i = 0; i < naxis; i++) {
+    for (int i = 0; i < naxis; i++) {
       *(ivalp++) = wcsp->colax[i];
     }
     break;
 
   case WCS_CNAME:
-    for (i = 0; i < naxis; i++) {
+    for (int i = 0; i < naxis; i++) {
       wcsutil_strcvt(72, ' ', 0, wcsp->cname[i], cvalp);
       cvalp += 72;
     }
     break;
   case WCS_CRDER:
-    for (i = 0; i < naxis; i++) {
+    for (int i = 0; i < naxis; i++) {
       *(dvalp++) = wcsp->crder[i];
     }
     break;
   case WCS_CSYER:
-    for (i = 0; i < naxis; i++) {
+    for (int i = 0; i < naxis; i++) {
       *(dvalp++) = wcsp->csyer[i];
     }
     break;
   case WCS_CZPHS:
-    for (i = 0; i < naxis; i++) {
+    for (int i = 0; i < naxis; i++) {
       *(dvalp++) = wcsp->czphs[i];
     }
     break;
   case WCS_CPERI:
-    for (i = 0; i < naxis; i++) {
+    for (int i = 0; i < naxis; i++) {
       *(dvalp++) = wcsp->cperi[i];
     }
     break;
@@ -759,7 +776,7 @@ int wcsget_(const int *wcs, const int *what, void *value)
     break;
 
   case WCS_OBSGEO:
-    for (i = 0; i < 6; i++) {
+    for (int i = 0; i < 6; i++) {
       *(dvalp++) = wcsp->obsgeo[i];
     }
     break;
@@ -859,40 +876,40 @@ int wcsget_(const int *wcs, const int *what, void *value)
     *ivalp = wcsp->cubeface;
     break;
   case WCS_TYPES:
-    for (i = 0; i < naxis; i++) {
+    for (int i = 0; i < naxis; i++) {
       *(ivalp++) = wcsp->types[i];
     }
     break;
   case WCS_LIN:
     // Copy the contents of the linprm struct.
     iwcsp = (int *)(&(wcsp->lin));
-    for (l = 0; l < LINLEN; l++) {
+    for (size_t l = 0; l < LINLEN; l++) {
       *(ivalp++) = *(iwcsp++);
     }
     break;
   case WCS_CEL:
     // Copy the contents of the celprm struct.
     iwcsp = (int *)(&(wcsp->cel));
-    for (l = 0; l < CELLEN; l++) {
+    for (size_t l = 0; l < CELLEN; l++) {
       *(ivalp++) = *(iwcsp++);
     }
     break;
   case WCS_SPC:
     // Copy the contents of the spcprm struct.
     iwcsp = (int *)(&(wcsp->spc));
-    for (l = 0; l < SPCLEN; l++) {
+    for (size_t l = 0; l < SPCLEN; l++) {
       *(ivalp++) = *(iwcsp++);
     }
     break;
   case WCS_ERR:
     // Copy the contents of the wcserr struct.
     if (wcsp->err) {
-      iwcsp = (int *)(wcsp->err);
-      for (l = 0; l < ERRLEN; l++) {
+    iwcsp = (int *)(wcsp->err);
+      for (size_t l = 0; l < ERRLEN; l++) {
         *(ivalp++) = *(iwcsp++);
       }
     } else {
-      for (l = 0; l < ERRLEN; l++) {
+      for (size_t l = 0; l < ERRLEN; l++) {
         *(ivalp++) = 0;
       }
     }
@@ -1010,6 +1027,14 @@ int auxsize_(const int *aux, int sizes[2])
 
 //----------------------------------------------------------------------------
 
+int wcsenq_(const int *wcs, int *enquiry)
+
+{
+  return wcsenq((const struct wcsprm *)wcs, *enquiry);
+}
+
+//----------------------------------------------------------------------------
+
 int wcsprt_(const int *wcs)
 
 {
@@ -1114,7 +1139,7 @@ int wcsmix_(
 //----------------------------------------------------------------------------
 
 int wcsccs_(
-  struct wcsprm *wcs,
+  int *wcs,
   const double *lng2p1,
   const double *lat2p1,
   const double *lng1p2,
@@ -1130,8 +1155,8 @@ int wcsccs_(
   wcsutil_strcvt(4,  '\0', 1, clat, clat_);
   wcsutil_strcvt(71, '\0', 1, radesys, radesys_);
 
-  int status = wcsccs(wcs, *lng2p1, *lat2p1, *lng1p2, clng_, clat_,
-                      radesys_, *equinox, alt);
+  int status = wcsccs((struct wcsprm *)wcs, *lng2p1, *lat2p1, *lng1p2, clng_,
+                      clat_, radesys_, *equinox, alt);
 
   return status;
 }
@@ -1139,7 +1164,7 @@ int wcsccs_(
 //----------------------------------------------------------------------------
 
 int wcssptr_(
-  struct wcsprm *wcs,
+  int *wcs,
   int *i,
   char ctype[8])
 
@@ -1147,7 +1172,7 @@ int wcssptr_(
   char ctype_[9];
   wcsutil_strcvt(8, ' ', 1, ctype, ctype_);
 
-  int status = wcssptr(wcs, i, ctype_);
+  int status = wcssptr((struct wcsprm *)wcs, i, ctype_);
 
   wcsutil_strcvt(8, ' ', 0, ctype_, ctype);
 
@@ -1168,8 +1193,8 @@ int wcscopy_(
 
 void wcslib_version_(
   char *wcsver,
-  int  nchr)
+  int  *nchr)
 
 {
-  wcsutil_strcvt(nchr, ' ', 0, wcslib_version(0x0), wcsver);
+  wcsutil_strcvt(*nchr, ' ', 0, wcslib_version(0x0), wcsver);
 }
