@@ -1,6 +1,6 @@
 /*============================================================================
-  WCSLIB 8.2 - an implementation of the FITS WCS standard.
-  Copyright (C) 1995-2023, Mark Calabretta
+  WCSLIB 8.4 - an implementation of the FITS WCS standard.
+  Copyright (C) 1995-2024, Mark Calabretta
 
   This file is part of WCSLIB.
 
@@ -19,7 +19,7 @@
 
   Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
   http://www.atnf.csiro.au/people/Mark.Calabretta
-  $Id: wcshdr_f.c,v 8.2.1.1 2023/11/16 10:05:58 mcalabre Exp mcalabre $
+  $Id: wcshdr_f.c,v 8.4 2024/10/28 13:56:17 mcalabre Exp $
 *===========================================================================*/
 
 #include <stdio.h>
@@ -37,6 +37,14 @@
 #define wcsvcopy_ F77_FUNC(wcsvcopy, WCSVCOPY)
 #define wcsvfree_ F77_FUNC(wcsvfree, WCSVFREE)
 
+#ifdef BINDC
+  #undef  wcspih_
+  #define wcspih_ wcspih_c
+
+  #undef  wcsbth_
+  #define wcsbth_ wcsbth_c
+#endif
+
 //----------------------------------------------------------------------------
 
 int wcspih_(
@@ -162,7 +170,6 @@ int wcsvcopy_(const iptr wcspp, const int *i, int *wcs)
   // ...or by linset().
   wcsdst->lin.piximg   = 0x0;
   wcsdst->lin.imgpix   = 0x0;
-  wcsdst->lin.tmpcrd   = 0x0;
   wcsdst->lin.flag     = 0;
 
   return 0;
