@@ -1,6 +1,6 @@
 /*============================================================================
-  WCSLIB 8.2 - an implementation of the FITS WCS standard.
-  Copyright (C) 1995-2023, Mark Calabretta
+  WCSLIB 8.4 - an implementation of the FITS WCS standard.
+  Copyright (C) 1995-2024, Mark Calabretta
 
   This file is part of WCSLIB.
 
@@ -19,7 +19,7 @@
 
   Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
   http://www.atnf.csiro.au/people/Mark.Calabretta
-  $Id: wcsunits_f.c,v 8.2.1.1 2023/11/16 10:05:58 mcalabre Exp mcalabre $
+  $Id: wcsunits_f.c,v 8.4 2024/10/28 13:56:17 mcalabre Exp $
 *===========================================================================*/
 
 #include <stdio.h>
@@ -39,6 +39,26 @@
 #define wcsutrn_  F77_FUNC(wcsutrn,  WCSUTRN)
 #define wcsulex_  F77_FUNC(wcsulex,  WCSULEX)
 
+#ifdef BINDC
+  #undef  wcsunitse_
+  #define wcsunitse_ wcsunitse_c
+
+  #undef  wcsutrne_
+  #define wcsutrne_ wcsutrne_c
+
+  #undef  wcsulexe_
+  #define wcsulexe_ wcsulexe_c
+
+  #undef  wcsunits_
+  #define wcsunits_ wcsunits_c
+
+  #undef  wcsutrn_
+  #define wcsutrn_ wcsutrn_c
+
+  #undef  wcsulex_
+  #define wcsulex_ wcsulex_c
+#endif
+
 //----------------------------------------------------------------------------
 
 int wcsunitse_(
