@@ -1,7 +1,7 @@
 *=======================================================================
 *
-* PGSBOX 8.2 - draw curvilinear coordinate axes for PGPLOT.
-* Copyright (C) 1997-2023, Mark Calabretta
+* PGSBOX 8.4 - draw curvilinear coordinate axes for PGPLOT.
+* Copyright (C) 1997-2024, Mark Calabretta
 *
 * This file is part of PGSBOX.
 *
@@ -20,7 +20,7 @@
 *
 * Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
 * http://www.atnf.csiro.au/people/Mark.Calabretta
-* $Id: pgsbox.f,v 8.2.1.1 2023/11/16 10:05:59 mcalabre Exp mcalabre $
+* $Id: pgsbox.f,v 8.4 2024/10/28 13:56:18 mcalabre Exp $
 *=======================================================================
 *
 * PGSBOX draws and labels a curvilinear coordinate grid.  The caller
@@ -2457,7 +2457,7 @@
  450        CONTINUE
  460        K = K + 1
 
-            TEXT(K:) = ',  ' // TXT(2)
+            TEXT(K:) = ',  ' // TXT(2)(:76)
           END IF
         ELSE IF (TXT(2).NE.' ') THEN
 *         Identify second world coordinate only.
@@ -2609,8 +2609,6 @@
 *=======================================================================
 * This Fortran wrapper on PGSBOX exists solely to define fixed-length
 * CHARACTER arguments for cpgsbox().
-*
-* Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
 *-----------------------------------------------------------------------
       SUBROUTINE PGSBOK (BLC, TRC, IDENTS, OPT, LABCTL, LABDEN, CI,
      :  GCODE, TIKLEN, NG1, GRID1, NG2, GRID2, DOEQ, NLFUNC, NLC, NLI,
@@ -2638,8 +2636,6 @@
 *=======================================================================
 * This Fortran wrapper on PGLBOX exists solely to define fixed-length
 * CHARACTER arguments for cpglbox().
-*
-* Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
 *-----------------------------------------------------------------------
       SUBROUTINE PGLBOK (IDENTS, OPT, LABCTL, LABDEN, CI, GCODE, TIKLEN,
      :  NG1, GRID1, NG2, GRID2, DOEQ, NC, IC, CACHE, IERR)
