@@ -1,5 +1,5 @@
 /*============================================================================
-  WCSLIB 8.3 - an implementation of the FITS WCS standard.
+  WCSLIB 8.4 - an implementation of the FITS WCS standard.
   Copyright (C) 1995-2024, Mark Calabretta
 
   This file is part of WCSLIB.
@@ -19,7 +19,7 @@
 
   Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
   http://www.atnf.csiro.au/people/Mark.Calabretta
-  $Id: sundazel.c,v 8.3 2024/05/13 16:33:01 mcalabre Exp $
+  $Id: sundazel.c,v 8.4 2024/10/28 13:56:18 mcalabre Exp $
 *=============================================================================
 * Usage: sundazel [<option>] [<yyyymmdd>]
 *-----------------------------------------------------------------------------
@@ -152,7 +152,7 @@ int main(int argc, char **argv)
 
 {
   // Parse options.
-  char   *ident, mode[16];
+  char   *ident = 0x0, mode[16];
   int    date = 0, verbose = 0;
   double obslng = OBSLNG, obslat = OBSLAT, obstz = OBSTZ;
   double coord = 0.0, pole_az = 0.0, pole_el = 90.0, zlng = 180.0;
